PipeWrench |Build Status| |Coverage|
====================================

PipeWrench is a framework that aims to make it easy to implement a message processing pipeline.
        
Development is hosted on `Github <https://github.com/TokinT-Mac/PipeWrench.git>`_.

Copyright 2014 Taylor McKinnon This program is free software: you can 
redistribute it and/or modify it under the terms of the GNU General 
Public License as published by the Free Software Foundation, either 
version 3 of the License, or (at your option) any later version. This 
program is distributed in the hope that it will be useful, but WITHOUT 
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License 
for more details. You should have received a copy of the GNU General 
Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

.. |Build Status| image:: https://travis-ci.org/TokinT-Mac/PipeWrench.png?branch=master
   :target: https://travis-ci.org/TokinT-Mac/PipeWrench
   
.. |Coverage| image:: https://coveralls.io/repos/TokinT-Mac/PipeWrench/badge.png?branch=master 
   :target: https://coveralls.io/r/TokinT-Mac/PipeWrench?branch=master